class Intro:
     def __init__(self, 
     media_id = None,
                path = None,
                path_converted = None,
                video_time = None,
                sentences = None) -> None:
        
        

        self.path = path
        self.path_converted = path_converted
        self.video_time = video_time
        self.media_id = media_id
        self.sentences = sentences

 